@@ -1,14 +1,19 @@
 import json
 
 from django.contrib.auth.mixins import UserPassesTestMixin
-from django.http import Http404, HttpResponseBadRequest, HttpResponseRedirect
+from django.http import (
+    Http404,
+    HttpResponse,
+    HttpResponseBadRequest,
+    HttpResponseRedirect,
+)
 from django.shortcuts import redirect
 from django.utils.decorators import method_decorator
 from django.views.decorators.cache import never_cache
 from django.views.generic import base, detail, edit
 
 from . import registry
-from .forms import PageForm, SectionForm
+from .forms import ContactForm, PageForm, SectionForm
 
 
 class SectionView:
@@ -54,6 +59,17 @@ class SectionFormView(SectionView):
         return form_class(**kwargs)
 
 
+class ContactSectionFormView(SectionFormView):
+    """Contact section with bogus contact form"""
+
+    form_class = ContactForm
+
+    def form_valid(self, form):
+        response = HttpResponse(status=302)
+        response["Location"] = form.save(self.object.href)
+        return response
+
+
 class PageView(detail.DetailView):
     """View of a page with heterogeneous sections"""
 
@@ -107,6 +123,7 @@ class PageView(detail.DetailView):
                 view = registry.get_view(section, request)
                 form = view.get_form(method="post")
                 if form.is_valid():
+                    view.object = section
                     return view.form_valid(form)
                 section.invalid_form = form
 
