@@ -1,34 +1,31 @@
 from cms.decorators import section_view
-from cms.forms import ContactForm
-from cms.views import SectionFormView, SectionView
+from cms.views import ContactSectionFormView, SectionView
 from django.utils.translation import gettext_lazy as _
 
 
 @section_view
 class Text(SectionView):
     verbose_name = _("Text")
-    fields = ["content"]
     template_name = "text.html"
+    fields = ["content"]
 
 
 @section_view
 class Images(SectionView):
     verbose_name = _("Image(s)")
-    fields = ["images"]
     template_name = "images.html"
+    fields = ["images"]
 
 
 @section_view
 class Video(SectionView):
     verbose_name = _("Video")
-    fields = ["video"]
     template_name = "video.html"
+    fields = ["video"]
 
 
 @section_view
-class Contact(SectionFormView):
+class Contact(ContactSectionFormView):
     verbose_name = _("Contact")
-    fields = []
-    form_class = ContactForm
-    success_url = "/thanks/"
     template_name = "contact.html"
+    fields = ["content", "href"]
